@@ -351,6 +351,12 @@ GMM_STATUS GMM_STDCALL GmmLib::GmmXe_LPGTextureCalc::FillTexPlanar(GMM_TEXTURE_I
             pTexInfo->Flags.Gpu.CCS               = 0;
             pTexInfo->Flags.Gpu.UnifiedAuxSurface = 0;
             pTexInfo->Flags.Gpu.__NonMsaaTileYCcs = 0;
+            if (pGmmLibContext->GetSkuTable().FtrXe2Compression)
+            {
+                pTexInfo->Flags.Info.NotCompressed     = 1;
+                pTexInfo->Flags.Gpu.MCS                = 0;
+                pTexInfo->Flags.Gpu.IndirectClearColor = 0;
+            }
         }
     }
 
@@ -1204,7 +1210,7 @@ void GmmLib::GmmXe_LPGTextureCalc::SetPlanarOffsetInfo(GMM_TEXTURE_INFO *pTexInf
     {
         pTexInfo->OffsetInfo.PlaneXe_LPG.IsTileAlignedPlanes = true;
     }
-    for(uint8_t i = 1; i <= CreateParams.NoOfPlanes; i++)
+    for(uint32_t i = 1; i <= CreateParams.NoOfPlanes; i++)
     {
         pTexInfo->OffsetInfo.PlaneXe_LPG.X[i] = CreateParams.PlaneOffset.X[i];
         pTexInfo->OffsetInfo.PlaneXe_LPG.Y[i] = CreateParams.PlaneOffset.Y[i];
@@ -1222,7 +1228,7 @@ void GmmLib::GmmXe_LPGTextureCalc::SetPlanarOffsetInfo_2(GMM_TEXTURE_INFO *pTexI
     {
         pTexInfo->OffsetInfo.PlaneXe_LPG.IsTileAlignedPlanes = true;
     }
-    for(uint8_t i = 1; i <= CreateParams.NoOfPlanes; i++)
+    for(uint32_t i = 1; i <= CreateParams.NoOfPlanes; i++)
     {
         pTexInfo->OffsetInfo.PlaneXe_LPG.X[i] = CreateParams.PlaneOffset.X[i];
         pTexInfo->OffsetInfo.PlaneXe_LPG.Y[i] = CreateParams.PlaneOffset.Y[i];
